@@ -19,14 +19,14 @@ class Buildpack:
         python = f'''FROM python:3.9.5-slim-buster\nWORKDIR /app\nCOPY requirements.txt .\nRUN pip install -r requirements.txt\nCOPY . .\nEXPOSE 8000\nCMD {entrypoint}'''
         return python
 
-    def dockercompose(self, port):
-        python = f"version: '3.8'\nservices:\n    app:\n        container_name: {self.project}\n        image: {self.project}\n        restart: always\n        ports:\n            - {port}:8000"
+    def dockercompose(self):
+        python = f"version: '3.8'\nservices:\n    app:\n        container_name: {self.project}\n        image: {self.project}\n        restart: always\n        ports:\n            - [PORT]:8000"
         return python
 
-    def generateDockerfile(self, file, save_location, port):
+    def generateDockerfile(self, file, save_location):
         script = self.parseScript(file)
         dockerfile = self.dockerfiles(script)
-        dockercompose = self.dockercompose(port=port)
+        dockercompose = self.dockercompose()
         file = open(f"{save_location}/Dockerfile", "w")
         with file as f:
             f.write(dockerfile)
