@@ -1,4 +1,4 @@
 from buildpack import Buildpack
 bp = Buildpack(f"myapp")
 if __name__ == "__main__":
-    bp.generateDockerfile("./Shonkufile")
\ No newline at end of file
+    bp.generateDockerfile("./Shonkufile", ".", 4000)
\ No newline at end of file
